#!/bin/bash

# set time
set_time () {
	TIME=$1

	if [ -z $TIME ]; then
		hour=`echo $TIME | cut -d: -f1 | tr -cd 0-9`
		minute=`echo $TIME | cut -d: -f2 | tr -cd 0-9`
	fi
}


set_date () {
	DATE=$1

	DATE_COUNT=`echo $DATE | tr -cd '/' | wc -c`

	if [ $DATE_COUNT -eq 2 ]; then
		year=`echo $DATE | cut -d'/' -f1 | tr -cd 0-9`
		month=`echo $DATE | cut -d'/' -f2 | tr -cd 0-9`
		day=`echo $DATE | cut -d'/' -f3 | tr -cd 0-9`
	elif [ $DATE_COUNT -eq 1 ]; then
		year=`date "+%Y"`
		month=`echo $DATE | cut -d'/' -f1 | tr -cd 0-9`
		day=`echo $DATE | cut -d'/' -f2 | tr -cd 0-9`
	elif [ $DATE_COUNT -eq 0 ] && [ -z $DATE ]; then
		year=`date "+%Y"`
		month=`date "+%m"`
		day=`echo $DATE | cut -d'/' -f1 | tr -cd 0-9`
	fi
}


# If it is a leap year, return 1.
is_leap_year () {
	year=$1

	if [ $(($year % 4)) -eq 0 ]; then
		if [ $(($year % 100)) -eq 0 ]; then
			if [ $(($year % 400)) -eq 0 ]; then
				FLAG=1
			else
				FLAG=0
			fi
		else
			FLAG=1
		fi
	else
		FLAG=0
	fi

    echo $FLAG
}


# Check if date is legal.
check_date () {
	year=$1
	month=$2
	day=$3
	days=`get_days $year $month`

	FLAG=0

	if [ $year -lt 1970 ]; then
		FLAG=1
	fi

	if [ $month -gt 12 ] || [ $month -lt 1 ]; then
		FLAG=1
	fi

	if [ $day -gt $days ] || [ $day -lt 1 ]; then
		FLAG=1
	fi

	echo $FLAG
}


# Check if time is legal.
check_time () {
	hour=$1
	minute=$2

	echo "$hour:$minute" | egrep -q "^([0-1][0-9]|2[0-3]):[0-5][0-9]$"
	FLAG=$?

	echo $FLAG
}


# Get the number of days per month.
get_days () {
    year=$1
    month=$2

    list="1 3 5 7 8 01 03 05 07 08 10 12"
    

    echo $list | egrep -q "(^|[[:space:]])$month"

    if [ $? -eq 0 ]; then
        days=31
    elif [ $month -eq 2 ]; then
        LEAP_FLAG=`is_leap_year $year`
        days=$((28 + $LEAP_FLAG))
    else
        days=30
    fi

    echo $days
}
